@@ -266,7 +266,9 @@ def attest() -> Optional[Dict[str, Any]]:
     """
     data_dir = os.path.join(str(pathlib.Path.home()), ".jaxl", "api")
     os.makedirs(data_dir, exist_ok=True)
-    attestation_path = Path(data_dir) / "attestation.json"
+    attestation_path = Path(data_dir) / os.environ.get(
+        "JAXL_ATTESTATION_FILE_NAME", "attestation.json"
+    )
     if attestation_path.exists():
         return cast(Dict[str, Any], json.loads(attestation_path.read_text()))
     attestation = _attest()
@@ -297,6 +299,16 @@ def _attest() -> Optional[Dict[str, Any]]:
     return response
 
 
+def encrypt(text: str) -> str:
+    attestation = attest()
+    assert attestation and "sk" in attestation
+    return (
+        Fernet(attestation["sk"])
+        .encrypt(json.dumps(text).encode("utf-8"))
+        .decode("utf-8")
+    )
+
+
 class JaxlApiModule(Enum):
     """Available API Modules"""
 
@@ -307,15 +319,24 @@ class JaxlApiModule(Enum):
     PAYMENT = 5
 
 
-def jaxl_api_client(module: JaxlApiModule) -> "AuthenticatedClient":
+def jaxl_api_client(
+    module: JaxlApiModule,
+    credentials: Optional[ApiCredentials] = None,
+    auth_token: Optional[str] = None,
+    set_org_id: bool = True,
+) -> "AuthenticatedClient":
     """Returns JaxlApiClient with auth token and device id preset."""
     attestation = attest()
-    auth_token = os.environ.get("JAXL_API_AUTH_TOKEN", None)
-    client = JaxlApiClient(_api_root(module))
+    auth_token = auth_token or os.environ.get("JAXL_API_AUTH_TOKEN", None)
+    client = JaxlApiClient(_api_root(module), credentials=credentials)
     assert attestation is not None, "Missing attestation"
     assert auth_token is not None, "Missing JAXL_API_AUTH_TOKEN"
     client.set_device_id(attestation["id"])
     client.set_auth_token(auth_token)
+    if set_org_id:
+        from jaxl.api.resources.orgs import first_org_id
+
+        client.set_org_id(first_org_id())
     return cast(AuthenticatedClient, client)
 
 
